"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QQGuildAdapter = exports.adapterConfigDefault = void 0;
const core_1 = require("@qq-guild-sdk/core");
const koishi_core_1 = require("koishi-core");
const bot_1 = require("./bot");
exports.adapterConfigDefault = {
    sandbox: true,
    endpoint: 'https://api.sgroup.qq.com/',
    authType: 'bot',
};
const createSession = (bot, msg) => {
    const { id: messageId, guildId, channelId, timestamp } = msg;
    const session = {
        selfId: bot.selfId,
        groupId: guildId,
        messageId,
        channelId,
        timestamp: typeof timestamp === 'string' ? Date.parse(timestamp) : +timestamp,
    };
    session.platform = 'qqguild';
    session.groupId = msg.guildId;
    session.channelId = msg.channelId;
    session.type = 'message';
    session.subtype = 'group';
    session.content = msg.content
        .replace(/<@!(.+)>/, (_, $1) => koishi_core_1.segment.at($1))
        .replace(/<#(.+)>/, (_, $1) => koishi_core_1.segment.sharp($1));
    session.author = {
        userId: msg.author.id,
        username: msg.author.username,
        avatar: msg.author.avatar,
        isBot: false,
    };
    session.userId = session.author.userId;
    return new koishi_core_1.Session(bot.app, session);
};
class QQGuildAdapter extends koishi_core_1.Adapter {
    config;
    constructor(app) {
        super(app, bot_1.QQGuildBot);
        if (!this.app.options.qqguild)
            throw new Error('no options');
        this.config = { ...exports.adapterConfigDefault, ...this.app.options.qqguild };
    }
    async start() {
        this.bots.forEach(async (bot) => {
            const innerBot = new core_1.Bot(this.config);
            bot.$innerBot = innerBot;
            await innerBot.startClient(this.config.indents);
            // innerBot.on('ready', bot.resolve)
            innerBot.on('message', (msg) => {
                const session = createSession(bot, msg);
                if (session)
                    this.dispatch(session);
            });
            await new Promise((res, rej) => {
                innerBot.on('ready', async () => {
                    const me = await innerBot.me;
                    bot.avatar = me.avatar;
                    bot.isBot = me.bot;
                    bot.username = me.username;
                    bot.selfId = me.id;
                    bot.status = koishi_core_1.Bot.Status.GOOD;
                    res(0);
                });
            });
        });
    }
    async stop() {
        return;
    }
}
exports.QQGuildAdapter = QQGuildAdapter;
